"use strict";

/* exported logger */

var AbstractAdminPanel = require('./AbstractAdminPanel');

var logger = require('../../logger');

var Functions = require('../../Functions');
var GuiConnector = require('../../GuiConnector');
var Promise = require("bluebird");

function MapsAdminPanel(params) {
  var self = this;
  AbstractAdminPanel.call(self, params);
  self._createGui();

  $(self.getElement()).addClass("projects-tab");

}

MapsAdminPanel.prototype = Object.create(AbstractAdminPanel.prototype);
MapsAdminPanel.prototype.constructor = MapsAdminPanel;

MapsAdminPanel.prototype._createGui = function() {
  var self = this;
  var projectsDiv = Functions.createElement({
    type : "div",
  });
  self.getElement().appendChild(projectsDiv);

  var dataDiv = Functions.createElement({
    type : "div",
    style : "display:table; width:100%",
  });
  projectsDiv.appendChild(dataDiv);

  dataDiv.appendChild(self._createMenuRow());
  dataDiv.appendChild(self._createProjectTableRow());
  dataDiv.appendChild(self._createMenuRow());

};

MapsAdminPanel.prototype._createMenuRow = function() {
  var self = this;
  var menuRow = Functions.createElement({
    type : "div",
    className : "menu-row",
    style : "display:table-row; margin:10px",
  });

  var addProjectButton = Functions.createElement({
    type : "button",
    name : "addProject",
    content : '<span class="ui-icon ui-icon-circle-plus"></span>&nbsp;ADD PROJECT',
    onclick : function() {
      return self.onAddClicked().then(null, GuiConnector.alert);
    },
  });
  var refreshButton = Functions.createElement({
    type : "button",
    name : "refreshProject",
    content : '<span class="ui-icon ui-icon-refresh"></span>&nbsp;REFRESH',
    onclick : function() {
      return self.onRefreshClicked().then(null, GuiConnector.alert);
    },
  });
  menuRow.appendChild(addProjectButton);
  menuRow.appendChild(refreshButton);
  return menuRow;
};

MapsAdminPanel.prototype._createProjectTableRow = function() {
  var projectsRow = Functions.createElement({
    type : "div",
    style : "display:table-row; width:100%",
  });

  var projectsTable = Functions.createElement({
    type : "table",
    name : "projectsTable",
    className : "display",
    style : "width:100%",
  });
  projectsRow.appendChild(projectsTable);

  $(projectsTable).DataTable({
    columns : [ {
      title : 'ProjectId',
    }, {
      title : 'Name',
    }, {
      title : 'Disease',
    }, {
      title : 'Organism',
    }, {
      title : 'Status',
    }, {
      title : 'Edit',
    }, {
      title : 'Remove',
    }, ],
  });
  return projectsRow;
}

MapsAdminPanel.prototype.init = function() {
  var self = this;
  return ServerConnector.getProjects().then(function(projects) {
    return self.setProjects(projects);
  }).then(function() {
    $(window).trigger('resize');
  });
};

MapsAdminPanel.prototype.projectToTableRow = function(project) {
  var self = this;
  var disease = self.getHtmlStringLink(project.getDisease());
  var organism =  self.getHtmlStringLink(project.getOrganism());

  var row = [ project.getProjectId(), // 
  project.getName(), //
  disease, // 
  organism, // 
  project.getStatus(), //
  "<button name='showEditDialog' data='" + project.getProjectId() + "'>EDIT</button>", //
  "<button name='removeProject' data='" + project.getProjectId() + "'>REMOVE</button>", // 
  ];
  return row;
}

MapsAdminPanel.prototype.getHtmlStringLink = function(annotation) {
  var self = this;
  if (annotation != undefined && annotation != null) {
    var link = self.getGuiUtils().createAnnotationLink(annotation, true);
    var tmp = document.createElement("div");
    tmp.appendChild(link);
    return tmp.innerHTML;
  } else {
    return "N/A";
  }

};

MapsAdminPanel.prototype.setProjects = function(projects) {
  var self = this;
  var dataTable = $($("[name='projectsTable']", self.getElement())[0]).DataTable();
  var data = [];
  for (var i = 0; i < projects.length; i++) {
    data.push(self.projectToTableRow(projects[i]));
  }
  dataTable.clear().rows.add(data).draw();

  $("[name='projectsTable']", self.getElement()).on("click", "[name='removeProject']", function() {
    var button = this;
    return self.removeProject($(button).attr("data")).then(null, GuiConnector.alert);
  });

  $("[name='projectsTable']", self.getElement()).on("click", "[name='showEditDialog']", function() {
    var button = this;
    return self.showEditDialog($(button).attr("data")).then(null, GuiConnector.alert);
  });
}

MapsAdminPanel.prototype.onAddClicked = function() {
  return Promise.reject(new Error("Not implemented"));
};
MapsAdminPanel.prototype.onRefreshClicked = function() {
  return Promise.reject(new Error("Not implemented"));
};
MapsAdminPanel.prototype.showEditDialog = function(id) {
  return Promise.reject(new Error("Not implemented"));
};
MapsAdminPanel.prototype.removeProject = function(id) {
  return Promise.reject(new Error("Not implemented"));
};

module.exports = MapsAdminPanel;
